dataframe from which to learn the parent sets.(required)
method
Method to be used. Possible values: "is" (independence selection), "sq" (sequential selection). (default: is)
indeg
Maximum number of parents (default: 6)
time
Maximum Execution time (default: 3600)
scorefunction
Chosen score function. Possible choices: BIC, BDeu (default: bic)
alpha
(if BDeu is chosen) equivalent sample size parameter (default: 1.0)
cores
Number of machine cores to use. If 0, all are used. (default: 1)
verbose
Verbose level (default: 0)
Value
Cache of parent sets
Details
Usually the first step in the learning of a Bayesian network.
The input data is required to be complete and discrete.
Accordingly missing values in the input data.frame will be ignored, and all numeric values will be converted to integers.